import { computed } from '@vue/composition-api';
import axios from 'axios';
import { usePromise } from '@vue-composable/core';

/* istanbul ignore next  */
const _axios = axios || (globalThis && globalThis.axios);
function useAxios(config) {
    /* istanbul ignore next  */
    (true !== 'production') &&
        !_axios &&
        console.warn(`[axios] not installed, please install it`);
    const axiosClient = _axios.create(config);
    const client = computed(() => axiosClient);
    const use = usePromise(async (request) => {
        return axiosClient.request(request);
    });
    const data = computed(() => (use.result.value && use.result.value.data) ||
        (use.error.value &&
            use.error.value.response &&
            use.error.value.response.data) ||
        null);
    const status = computed(() => (use.result.value && use.result.value.status) ||
        (use.error.value &&
            use.error.value.response &&
            use.error.value.response.status) ||
        null);
    const statusText = computed(() => (use.result.value && use.result.value.statusText) ||
        (use.error.value &&
            use.error.value.response &&
            use.error.value.response.statusText) ||
        null);
    return {
        ...use,
        client,
        data,
        status,
        statusText
    };
}

export { useAxios };
