var vueComposableAxios = (function (exports, compositionApi, axios) {
    'use strict';

    axios = axios && axios.hasOwnProperty('default') ? axios['default'] : axios;

    function usePromise(fn) {
        if (!fn) {
            throw new Error(`[usePromise] argument can't be '${fn}'`);
        }
        if (typeof fn !== "function") {
            throw new Error(`[usePromise] expects function, but received ${typeof fn}`);
        }
        const loading = compositionApi.ref(false);
        const error = compositionApi.ref(null);
        const result = compositionApi.ref(null);
        const promise = compositionApi.ref();
        const exec = async (...args) => {
            loading.value = true;
            error.value = null;
            result.value = null;
            const currentPromise = (promise.value = fn(...args));
            try {
                const r = await currentPromise;
                if (promise.value === currentPromise) {
                    result.value = r;
                }
                return r;
            }
            catch (er) {
                if (promise.value === currentPromise) {
                    error.value = er;
                    result.value = null;
                }
                return undefined;
            }
            finally {
                if (promise.value === currentPromise) {
                    loading.value = false;
                }
            }
        };
        return {
            exec,
            result,
            promise,
            loading,
            error
        };
    }

    /* istanbul ignore next  */
    const _axios = axios || (globalThis && globalThis.axios);
    function useAxios(config) {
        /* istanbul ignore next  */
        
            !_axios &&
            console.warn(`[axios] not installed, please install it`);
        const axiosClient = _axios.create(config);
        const client = compositionApi.computed(() => axiosClient);
        const use = usePromise(async (request) => {
            return axiosClient.request(request);
        });
        const data = compositionApi.computed(() => (use.result.value && use.result.value.data) ||
            (use.error.value &&
                use.error.value.response &&
                use.error.value.response.data) ||
            null);
        const status = compositionApi.computed(() => (use.result.value && use.result.value.status) ||
            (use.error.value &&
                use.error.value.response &&
                use.error.value.response.status) ||
            null);
        const statusText = compositionApi.computed(() => (use.result.value && use.result.value.statusText) ||
            (use.error.value &&
                use.error.value.response &&
                use.error.value.response.statusText) ||
            null);
        return {
            ...use,
            client,
            data,
            status,
            statusText
        };
    }

    exports.useAxios = useAxios;

    return exports;

}({}, vueCompositionApi, axios));
